exceptiontools.TieChainError
============================

.. inheritance-diagram:: abjad.tools.exceptiontools.TieChainError.TieChainError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.TieChainError.TieChainError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.TieChainError.TieChainError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TieChainError.TieChainError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TieChainError.TieChainError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TieChainError.TieChainError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TieChainError.TieChainError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TieChainError.TieChainError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TieChainError.TieChainError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TieChainError.TieChainError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
